import {
  isArray,
  isBinaryArray,
  isObject,
  isPrimitive,
  isSymbol
} from "./chunk-NXVGWT4R.js";

// src/common/data/object.ts
function objectMap(obj, fn) {
  if (!isObject(obj))
    return {};
  return Object.fromEntries(
    Object.entries(obj).map(([k, v]) => {
      const r = fn(k, v);
      if (isArray(r) && r.length === 2)
        return r;
      return [k, r];
    }).filter((v) => v != null)
  );
}
function objectMergeDisposable(a, b) {
  if (b.dispose && a.dispose) {
    b.dispose.add(a.dispose);
  }
  return Object.assign(a, b);
}
function objectIsEmpty(obj) {
  return Object.keys(obj).length <= 0;
}
function objectPick(obj, ...keys) {
  return Object.fromEntries(keys.filter((key) => key in obj).map((key) => [key, obj[key]]));
}
function objectInclusivePick(obj, ...keys) {
  return Object.fromEntries(keys.map((key) => [key, obj[key]]));
}
function objectOmit(obj, ...keys) {
  return Object.fromEntries(Object.entries(obj).filter(([key]) => !keys.includes(key)));
}
function objectPlain(obj, opt) {
  const {
    maxDepth = 99,
    circleValue,
    maxDepthValue,
    errorTrace = true,
    filter = () => true,
    keepAsIs = () => false
  } = opt ?? {};
  const cycle = [];
  function handleObject(obj2, depth) {
    if (depth > maxDepth)
      return maxDepthValue;
    if (keepAsIs(obj2))
      return obj2;
    if (isSymbol(obj2))
      return String(obj2);
    if (isPrimitive(obj2))
      return obj2;
    if (cycle.includes(obj2))
      return circleValue;
    cycle.push(obj2);
    if (obj2 instanceof Date)
      return obj2.toISOString();
    if (obj2 instanceof RegExp)
      return obj2.toString();
    if (obj2 instanceof Map)
      obj2 = Object.fromEntries(obj2);
    if (obj2 instanceof Set || isBinaryArray(obj2))
      obj2 = Array.from(obj2);
    if (obj2 instanceof Error)
      return `${obj2.name || "Error"}: ${obj2.message}${errorTrace ? `
${obj2.stack}` : ""}`;
    if (Array.isArray(obj2)) {
      return obj2.filter(filter).map((o) => handleObject(o, depth + 1));
    }
    const nobj = {};
    for (const key in obj2) {
      const value = obj2[key];
      if (filter(value))
        nobj[key] = handleObject(value, depth + 1);
    }
    return nobj;
  }
  return handleObject(obj, 0);
}

export {
  objectMap,
  objectMergeDisposable,
  objectIsEmpty,
  objectPick,
  objectInclusivePick,
  objectOmit,
  objectPlain
};
//# sourceMappingURL=chunk-XOOIUMF2.js.map