import "../../chunk-HMRSQHLY.js";
import "../../chunk-UMUHNSGZ.js";
import "../../chunk-SRT6T6F5.js";
import {
  bitfield,
  createBinaryStreamDecoder,
  createBinaryStreamEncoder,
  encodeJson
} from "../../chunk-RMPE2GT3.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-QQSABUQG.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-264HKVNG.js";
import "../../chunk-YP5GPYKL.js";
import "../../chunk-LKHGPAZI.js";
import "../../chunk-FLFB2K34.js";
import "../../chunk-HST4VI64.js";
import "../../chunk-A7SUGWC3.js";
import "../../chunk-RO734M2N.js";
import "../../chunk-K6VSSZK7.js";
import "../../chunk-MYPACQAF.js";
import "../../chunk-W4PZPEDX.js";
import "../../chunk-IQFZHKL7.js";
import "../../chunk-NUUT5WGY.js";
import "../../chunk-AJ3WFXQE.js";
import "../../chunk-BUMAFR52.js";
import "../../chunk-AP2LHZQJ.js";
import "../../chunk-TECA6FV3.js";
import "../../chunk-UH2XTXP7.js";
import "../../chunk-MPAXUMZ5.js";
import "../../chunk-PJDBG5VS.js";
import "../../chunk-MY57YSRI.js";
import "../../chunk-RLHKRW4I.js";
import "../../chunk-UV5YY7RE.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-PAMCEPLQ.js";
import "../../chunk-JSFYTABJ.js";
import "../../chunk-7ITBV6UM.js";
import "../../chunk-RZKR2WPX.js";
import "../../chunk-RG6OSZW5.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-XGHGEMIC.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-6C3JJJOL.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-KQSQJAHU.js";
import "../../chunk-JC22THP7.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-XOOIUMF2.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-M6LJR6SZ.js";
import "../../chunk-NXVGWT4R.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-O4U55KGC.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-MVRB7Y7X.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import {
  Uint8ArrayToHexDump,
  equalBinary,
  toHex
} from "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/bin/index.spec.ts
describe("encoder", () => {
  it("should write a stream", () => {
    const stream = createBinaryStreamEncoder();
    stream.writeUint32(1);
    stream.write({ a: "99" });
    stream.writeBytes([1, 2, 3], 3);
    stream.write(123);
    const bin = stream.getUint8Array();
    expect(Uint8ArrayToHexDump(bin)).toMatchInlineSnapshot(`
      "0000  01 00 00 00 76 01 01 61 77 02 39 39 01 02 03 7d  ....v..aw.99...}
      0010  bb 01                                            \xBB.              "
    `);
    expect(stream.getLength()).toBe(18);
    const readStream = createBinaryStreamDecoder(bin);
    expect(readStream.getOffset()).toBe(0);
    expect(readStream.readUint32()).toBe(1);
    expect(readStream.getOffset()).toBe(4);
    expect(readStream.read()).toEqual({ a: "99" });
    expect(readStream.readBytes(3)).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
    expect(readStream.read()).toBe(123);
    expect(readStream.getOffset()).toBe(bin.length);
  });
  it("should bitfield", () => {
    const bf = bitfield(1);
    bf.setBit(4);
    expect(bf.getValue()).toBe(17);
    bf.setBit(0, false);
    expect(bf.getValue()).toBe(16);
    bf.setBit(1);
    bf.setBit(5);
    bf.setBit(16);
    expect(bf.getValue().toString(2)).toMatchInlineSnapshot(
      '"10000000000110010"'
    );
    expect(bf.getValue()).toBe(65586);
    expect(bf.getBit(0)).toBe(false);
    expect(bf.getBit(4)).toBe(true);
    bf.toggleBit(4);
    expect(bf.getBit(4)).toBe(false);
    expect(bf.getValue()).toBe(65570);
  });
  it("should var bin", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeIntVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(128)).toMatchInlineSnapshot('"8002"');
    expect(enc(-1)).toMatchInlineSnapshot('"41"');
    expect(enc(-691529286)).toMatchInlineSnapshot('"c699bf9305"');
    expect(enc(691529286)).toMatchInlineSnapshot('"8699bf9305"');
  });
  it("should var bin uint", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeUintVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(127)).toMatchInlineSnapshot('"7f"');
    expect(enc(128)).toMatchInlineSnapshot(`"8001"`);
    expect(enc(255)).toMatchInlineSnapshot('"ff01"');
    expect(enc(256)).toMatchInlineSnapshot('"8002"');
    expect(enc(691529286)).toMatchInlineSnapshot('"c6ccdfc902"');
  });
  it("should be consistent", () => {
    const bin1 = encodeJson({
      a: 1,
      b: 2
    });
    const bin2 = encodeJson({
      b: 2,
      a: 1
    });
    expect(equalBinary(bin1, bin2)).toBe(true);
  });
});
//# sourceMappingURL=index.spec.js.map