import { TimerExecFunction } from '../dispose-utils.js';
import { Disposer, DisposerFunction } from '../dispose-types.js';
import './emitter.js';
import { Channel } from './channel.js';
import '../global.js';
import '../log/log.js';
import '../log/log-console-original.js';
import '../dispose-defer.js';
import '../log/log-base.js';

/**
 * Channel that buffers if not connected.
 * The actual channel can be removed and replaced.
 */
declare class ResillientChannel extends Channel {
    private channel?;
    private buffer;
    dispose: ((strictSync?: boolean) => void | Promise<any>) & {
        disposed: number;
        add: (obj?: Disposer | undefined) => DisposerFunction | undefined;
        remove: (disposable: Disposer) => void | Promise<void>;
        track: (obj?: Disposer | undefined) => DisposerFunction | undefined;
        untrack: (disposable: Disposer) => void | Promise<void>;
        dispose: (strictSync?: boolean) => void | Promise<any>;
        disposeSync: () => void;
        sync: () => void;
        exec: (strictSync?: boolean) => void | Promise<any>;
        getSize(): number;
        isDisposed(): boolean;
    } & {
        timeout: (fn: TimerExecFunction, timeout?: number) => DisposerFunction | undefined;
        interval: (fn: TimerExecFunction, interval?: number) => DisposerFunction | undefined;
        intervalPause: (fn: TimerExecFunction, interval?: number) => DisposerFunction | undefined;
        on: (emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]) => DisposerFunction | undefined;
        once: (emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]) => DisposerFunction | undefined;
    };
    private postMessageRaw;
    /** Post all buffered messages */
    flushBuffer(): void;
    /** Reset buffer without force sending */
    emptyBuffer(): void;
    /**
     * Set a new channel and flush buffer
     */
    setChannel(channel?: Channel): void;
    /** @deprecated use `setChannel(undefined)` */
    deleteChannel(): void;
    postMessage(data: Uint8Array | string): void;
    get isConnected(): boolean;
}

export { ResillientChannel };
