import {
  decodeJson,
  encodeJson
} from "../../chunk-RMPE2GT3.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-QQSABUQG.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RO734M2N.js";
import {
  useRPC,
  useRPCHub
} from "../../chunk-IQFZHKL7.js";
import {
  createLocalChannelPair
} from "../../chunk-AP2LHZQJ.js";
import "../../chunk-TECA6FV3.js";
import "../../chunk-MY57YSRI.js";
import "../../chunk-RLHKRW4I.js";
import "../../chunk-UV5YY7RE.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-PAMCEPLQ.js";
import "../../chunk-JSFYTABJ.js";
import "../../chunk-7ITBV6UM.js";
import "../../chunk-RZKR2WPX.js";
import "../../chunk-RG6OSZW5.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-XGHGEMIC.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-6C3JJJOL.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-KQSQJAHU.js";
import "../../chunk-JC22THP7.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-XOOIUMF2.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-M6LJR6SZ.js";
import "../../chunk-NXVGWT4R.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-O4U55KGC.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-MVRB7Y7X.js";
import {
  sleep
} from "../../chunk-FSDCRQB3.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/msg/rpc.spec.ts
import { MessageChannel } from "node:worker_threads";
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc async", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("hub", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("timeout async", async (done) => {
    const [f1, f2] = createLocalChannelPair();
    const rpc1 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_1`;
      }
    }, {
      post: (data) => {
        f1.postMessage(data);
      },
      on: (data) => f1.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const rpc2 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_2`;
      }
    }, {
      post: (data) => {
        f2.postMessage(data);
      },
      on: (data) => f2.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const r = await rpc1.echo("abc");
    expect(r).toMatchInlineSnapshot(`"abc_2"`);
    try {
      const r2 = await rpc1.echo("abc", 50);
      expect(false).toBe(true);
    } catch (err) {
      expect(err).toMatchInlineSnapshot(`[Error: rpc timeout on calling "echo"]`);
    }
  });
  it("async", async (done) => {
    function echo(n) {
      return n;
    }
    async function echoAsync(n) {
      return n;
    }
    expect(await echo(1)).toBe(1);
    expect(await echoAsync(2)).toBe(2);
  });
});
//# sourceMappingURL=rpc.spec.js.map